=======
Changes
=======

1.0.0
=====

- Add Django 3.x and 4.x compatibility
- Drop support for Python 2
- Python 3.6 is the minimum requirement

0.3
===

- Add Django 2.0 compatibility
- Extract ``MediaDefiningClass`` base class from ``MediaDefiningView``

0.2
===

- Specify different requirements in ``setup.py`` based on the current Python version
- Allow using inline JavaScript in media definitions (wrap with ``<script>`` tag)

0.1
===

- Initial release
